Documentation
==================

``grgrjax.newton``
-------------------
.. automodule:: grgrjax.newton
   :members:
   :undoc-members:
   :show-inheritance:

``grgrjax.jacs``
-------------------
.. automodule:: grgrjax.jacs
   :members:
   :undoc-members:
   :show-inheritance:
